@@ -39,3 +39,9 @@ cli_colors <- function(envir = parent.frame()) {
     span.spark = list(color = "darkgray")
   )
 }
+
+cli_internal_abort <- function(msg) {
+  cli_div(theme = cli_colors())
+  cli_abort(msg, call = NULL)
+  cli_end()
+}
