@@ -1,8 +1,5 @@
 test_that("Print method works", {
   sc <- test_spark_connect()
   test_table_mtcars()
-  expect_snapshot(
-    print(invoke(sc, "sql", "select * from mtcars limit 5")),
-  )
+  expect_message(print(invoke(sc, "sql", "select * from mtcars limit 5")))
 })
-
